@@ -13,7 +13,7 @@ bullets_with_header <- function(header, x) {
         format(x)
       }
     } else {
-      friendly_type_of(x)
+      obj_type_friendly(x)
     }
   }
   vals <- map_chr(x, as_simple)
@@ -21,12 +21,15 @@ bullets_with_header <- function(header, x) {
   cli::cli_li(paste0("{.field ", names(x), "}: ", vals))
 }
 
-modify_list <- function(.x, ...) {
+modify_list <- function(.x, ..., error_call = caller_env()) {
   dots <- list2(...)
   if (length(dots) == 0) return(.x)
 
   if (!is_named(dots)) {
-    abort("All components of ... must be named")
+    cli::cli_abort(
+      "All components of {.arg ...} must be named.",
+      call = error_call
+    )
   }
 
   out <- .x[!names(.x) %in% names(dots)]
@@ -40,22 +43,31 @@ modify_list <- function(.x, ...) {
 }
 
 
-sys_sleep <- function(seconds, fps = 10) {
-  check_number(seconds, "`seconds`")
+sys_sleep <- function(seconds,
+                      task,
+                      fps = 10,
+                      progress = getOption("httr2_progress", TRUE)) {
+  check_number_decimal(seconds)
 
   if (seconds == 0) {
     return(invisible())
   }
 
+  if (!progress) {
+    cli::cli_alert("Waiting {ceiling(seconds)}s {task}")
+    Sys.sleep(seconds)
+    return(invisible())
+  }
+
   start <- cur_time()
   signal("", class = "httr2_sleep", seconds = seconds)
 
   cli::cli_progress_bar(
-    format = "Waiting {round(seconds)}s to retry {cli::pb_bar}",
+    format = "Waiting {ceiling(seconds)}s {task} {cli::pb_bar}",
     total = seconds * fps
   )
 
-  while({left <- start + seconds - cur_time(); left > 0}) {
+  while ({left <- start + seconds - cur_time(); left > 0}) {
     Sys.sleep(min(1 / fps, left))
     cli::cli_progress_update(set = (seconds - left) * fps)
   }
@@ -66,23 +78,6 @@ sys_sleep <- function(seconds, fps = 10) {
 
 cur_time <- function() proc.time()[[3]]
 
-check_string <- function(x, name, optional = TRUE) {
-  if (is_string(x) && !is.na(x)) {
-    return()
-  }
-  if (optional && is.null(x)) {
-    return()
-  }
-  abort(glue("{name} must be a string"))
-}
-
-check_number <- function(x, name) {
-  if ((is_double(x, n = 1) || is_integer(x, n = 1)) && !is.na(x)) {
-    return()
-  }
-  abort(glue("{name} must be a number"))
-}
-
 is_error <- function(x) inherits(x, "error")
 
 unix_time <- function() as.integer(Sys.time())
@@ -128,7 +123,7 @@ base64_url_rand <- function(bytes = 32) {
 #' @export
 #' @examples
 #' fun <- function() {
-#'   request("https://httr2.r-lib.org") %>% req_perform()
+#'   request("https://httr2.r-lib.org") |> req_perform()
 #' }
 #' with_verbosity(fun())
 with_verbosity <- function(code, verbosity = 1) {
@@ -163,7 +158,7 @@ http_date <- function(x = Sys.time()) {
 }
 
 parse_http_date <- function(x) {
-  check_string(x, "`x`")
+  check_string(x)
 
   withr::local_locale(LC_TIME = "C")
 
@@ -185,3 +180,108 @@ local_write_lines <- function(..., .env = caller_env()) {
   writeLines(c(...), path)
   path
 }
+
+check_function2 <- function(x,
+                            ...,
+                            args = NULL,
+                            allow_null = FALSE,
+                            arg = caller_arg(x),
+                            call = caller_env()) {
+  check_function(
+    x = x,
+    allow_null = allow_null,
+    arg = arg,
+    call = call
+  )
+
+  if (!is.null(x)) {
+    .check_function_args(
+      f = x,
+      expected_args = args,
+      arg = arg,
+      call = call
+    )
+  }
+}
+
+# Basically copied from rlang. Can be removed when https://github.com/r-lib/rlang/pull/1652
+# is merged
+.check_function_args <- function(f,
+                                 expected_args,
+                                 arg,
+                                 call) {
+  if (is_null(expected_args)) {
+    return(invisible(NULL))
+  }
+
+  actual_args <- fn_fmls_names(f) %||% character()
+  missing_args <- setdiff(expected_args, actual_args)
+  if (is_empty(missing_args)) {
+    return(invisible(NULL))
+  }
+
+  n_expected_args <- length(expected_args)
+  n_actual_args <- length(actual_args)
+
+  if (n_actual_args == 0) {
+    arg_info <- "instead it has no arguments"
+  } else {
+    arg_info <- paste0("it currently has {.arg {actual_args}}")
+  }
+
+  cli::cli_abort(
+    paste0("{.arg {arg}} must have the {cli::qty(n_expected_args)}argument{?s} {.arg {expected_args}}; ", arg_info, "."),
+    call = call,
+    arg = arg
+  )
+}
+
+# This is inspired by the C interface of `cli_progress_bar()` which has just
+# 2 arguments: `total` and `config`
+create_progress_bar <- function(total,
+                                name,
+                                config,
+                                env = caller_env(),
+                                config_arg = caller_arg(config),
+                                error_call = caller_env()) {
+  if (is_false(config)) {
+    return(list(
+      update = function(...) {},
+      done = function() {}
+    ))
+  }
+
+  if (is.null(config) || is_bool(config)) {
+    args <- list()
+  } else if (is_scalar_character(config)) {
+    args <- list(name = config)
+  } else if (is.list(config)) {
+    args <- config
+  } else {
+    stop_input_type(
+      config,
+      what = c("a bool", "a string", "a list"),
+      arg = config_arg,
+      call = error_call
+    )
+  }
+
+  args$name <- args$name %||% name
+  # Can be removed if https://github.com/r-lib/cli/issues/630 is fixed
+  if (is.infinite(total)) {
+    total <- NA
+  }
+  args$total <- total
+  args$.envir <- env
+
+  id <- exec(cli::cli_progress_bar, !!!args)
+
+  list(
+    update = function(...) cli::cli_progress_update(..., id = id),
+    done = function() cli::cli_progress_done(id = id)
+  )
+}
+
+imap <- function(.x, .f, ...) {
+  map2(.x, names(.x), .f, ...)
+}
