@@ -3,7 +3,7 @@ test_that("req has basic print method", {
     req <- request("https://example.com")
     req
     req %>% req_body_raw("Test")
-    req %>% req_body_multipart(list("Test" = 1))
+    req %>% req_body_multipart("Test" = 1)
   })
 })
 
@@ -13,12 +13,13 @@ test_that("individually prints repeated headers", {
 
 test_that("print method obfuscates Authorization header unless requested", {
   req <- request("https://example.com") %>%
-    req_headers(Authorization = "SECRET")
+    req_auth_basic("user", "SECRET")
   output <- testthat::capture_messages(print(req))
   expect_false(any(grepl("SECRET", output)))
 
   output <- testthat::capture_messages(print(req, redact_headers = FALSE))
-  expect_true(any(grepl("SECRET", output)))
+  expect_true(any(grepl("Authorization: 'Basic", output)))
+  expect_false(any(grepl("REDACTED", output)))
 })
 
 test_that("check_request() gives useful error", {
